@@ -5,7 +5,6 @@ package Getopt::Mixed;
 #
 # Author: Christopher J. Madsen <perl@cjmweb.net>
 # Created: 1 Jan 1995
-# $Id: Mixed.pm 1712 2007-03-22 00:13:26Z cjm $
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the same terms as Perl itself.
@@ -15,7 +14,7 @@ package Getopt::Mixed;
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See either the
 # GNU General Public License or the Artistic License for more details.
 #
-# Process both single-character and extended options
+# ABSTRACT: getopt processing with both long and short options
 #---------------------------------------------------------------------
 
 require 5.000;
@@ -39,7 +38,7 @@ require Exporter;
 
 BEGIN
 {
-    $VERSION = '1.10';
+    $VERSION = '1.11';
 
     # The permissible settings for $order:
     $REQUIRE_ORDER   = 0;
@@ -392,6 +391,11 @@ __END__
 
 Getopt::Mixed - getopt processing with both long and short options
 
+=head1 VERSION
+
+This document describes version 1.11 of
+Getopt::Mixed, released August 25, 2012.
+
 =head1 SYNOPSIS
 
     use Getopt::Mixed;
@@ -569,7 +573,7 @@ and other arguments were in.
 First, you call Getopt::Mixed::init with the option descriptions.
 Then, you keep calling nextOption until it returns an empty list.
 Finally, you call Getopt::Mixed::cleanup when you're done.  The
-remaining (non-option) arguments will be found in @ARGV.
+remaining (non-option) arguments will be found in C<@ARGV>.
 
 Each call to nextOption returns a list of the next option, its value,
 and the option as the user typed it.  The value will be undefined if
@@ -643,17 +647,17 @@ A string of characters that can start options.  Default is "-".
 =item $badOption
 
 A reference to a function that is called when an unrecognized option
-is encountered.  The function receives three arguments.  $_[0] is the
-position in @ARGV where the option came from.  $_[1] is the option as
-the user typed it (including the option start character).  $_[2] is
+is encountered.  The function receives three arguments.  C<$_[0]> is the
+position in C<@ARGV> where the option came from.  C<$_[1]> is the option as
+the user typed it (including the option start character).  C<$_[2]> is
 either undef or a string describing the reason the option was not
 recognized (Currently, the only possible value is 'ambiguous', for a
 long option with several possible matches).  The option has already
-been removed from @ARGV.  To put it back, you can say:
+been removed from C<@ARGV>.  To put it back, you can say:
 
     splice(@ARGV,$_[0],0,$_[1]);
 
-The function can do anything you want to @ARGV.  It should return
+The function can do anything you want to C<@ARGV>.  It should return
 whatever you want nextOption to return.
 
 The default is a function that prints an error message and exits the
@@ -662,20 +666,20 @@ program.
 =item $checkArg
 
 A reference to a function that is called to make sure the argument
-type is correct.  The function receives four arguments.  $_[0] is the
-position in @ARGV where the option came from.  $_[1] is the text
+type is correct.  The function receives four arguments.  C<$_[0]> is the
+position in C<@ARGV> where the option came from.  C<$_[1]> is the text
 following the option, or undefined if there was no text following the
-option.  $_[2] is the name of the option as the user typed it
+option.  C<$_[2]> is the name of the option as the user typed it
 (including the option start character), suitable for error messages.
-$_[3] is the argument type specifier.
+C<$_[3]> is the argument type specifier.
 
-The function can do anything you want to @ARGV.  It should return
+The function can do anything you want to C<@ARGV>.  It should return
 the value for this option.
 
 The default is a function that prints an error message and exits the
 program if the argument is not the right type for the option.  You can
 also adjust the behavior of the default function by changing
-$intRegexp or $floatRegexp.
+C<$intRegexp> or C<$floatRegexp>.
 
 =item $intRegexp
 
@@ -707,12 +711,20 @@ changed afterwards.
 
 =item $checkType
 
-If you add new types to $typeChars, you should set this to a function
+If you add new types to C<$typeChars>, you should set this to a function
 which will check arguments of the new types.
 
 =back
 
-=head1 BUGS
+=head1 CONFIGURATION AND ENVIRONMENT
+
+Getopt::Mixed requires no configuration files or environment variables.
+
+=head1 INCOMPATIBILITIES
+
+None reported.
+
+=head1 BUGS AND LIMITATIONS
 
 =over 4
 
@@ -739,25 +751,50 @@ and do it yourself.
 
 =back
 
-=head1 LICENSE
-
-Getopt::Mixed is distributed under the same terms as Perl itself.
-
-This means it is distributed in the hope that it will be useful, but
-I<without any warranty>; without even the implied warranty of
-I<merchantability> or I<fitness for a particular purpose>.  See the
-GNU General Public License or the Artistic License for more details.
-
 =head1 AUTHOR
 
-Christopher J. Madsen E<lt>F<perl AT cjmweb.net>E<gt>
+Christopher J. Madsen  S<C<< <perl AT cjmweb.net> >>>
 
-Please send bug reports to F<bug-Getopt-Mixed AT rt.cpan.org>, or
-use the web interface at
-L<http://rt.cpan.org/Public/Bug/Report.html?Queue=Getopt-Mixed>
+Please report any bugs or feature requests
+to S<C<< <bug-Getopt-Mixed AT rt.cpan.org> >>>
+or through the web interface at
+L<< http://rt.cpan.org/Public/Bug/Report.html?Queue=Getopt-Mixed >>.
+
+You can follow or contribute to Getopt::Mixed's development at
+L<< http://github.com/madsen/getopt-mixed >>.
 
 Thanks are also due to Andreas Koenig for helping Getopt::Mixed
 conform to the standards for Perl modules and for answering a bunch of
 questions.  Any remaining deficiencies are my fault.
 
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 1995 by Christopher J. Madsen.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=head1 DISCLAIMER OF WARRANTY
+
+BECAUSE THIS SOFTWARE IS LICENSED FREE OF CHARGE, THERE IS NO WARRANTY
+FOR THE SOFTWARE, TO THE EXTENT PERMITTED BY APPLICABLE LAW. EXCEPT WHEN
+OTHERWISE STATED IN WRITING THE COPYRIGHT HOLDERS AND/OR OTHER PARTIES
+PROVIDE THE SOFTWARE "AS IS" WITHOUT WARRANTY OF ANY KIND, EITHER
+EXPRESSED OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
+WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. THE
+ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF THE SOFTWARE IS WITH
+YOU. SHOULD THE SOFTWARE PROVE DEFECTIVE, YOU ASSUME THE COST OF ALL
+NECESSARY SERVICING, REPAIR, OR CORRECTION.
+
+IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW OR AGREED TO IN WRITING
+WILL ANY COPYRIGHT HOLDER, OR ANY OTHER PARTY WHO MAY MODIFY AND/OR
+REDISTRIBUTE THE SOFTWARE AS PERMITTED BY THE ABOVE LICENSE, BE
+LIABLE TO YOU FOR DAMAGES, INCLUDING ANY GENERAL, SPECIAL, INCIDENTAL,
+OR CONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OR INABILITY TO USE
+THE SOFTWARE (INCLUDING BUT NOT LIMITED TO LOSS OF DATA OR DATA BEING
+RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU OR THIRD PARTIES OR A
+FAILURE OF THE SOFTWARE TO OPERATE WITH ANY OTHER SOFTWARE), EVEN IF
+SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF
+SUCH DAMAGES.
+
 =cut
